## Jupyter Notebook Viewer
* This is a utility which lets you preview Jupyter notebooks faster on your Linux machine, with a double click.
* Requires no internet and is faster.

## Installation
* Use `pip install nbviewer-gui` to install the package, and you can call the command line utility from the terminal by

```fish
nbviewer-gui notebook.ipynb
```
You can also use the `notebook.desktop` under the `nbviewergui` directory and create a desktop application, so that you can launch the script by double clicking the *.ipynb file.
